# Generated by Django 4.2.6 on 2024-03-24 15:52

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django_anchor_modeling.utils


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('django_anchor_modeling', '0002_sentinel_user'),
    ]

    operations = [
        migrations.AddField(
            model_name='transaction',
            name='created_by',
            field=models.ForeignKey(db_constraint=False, default=django_anchor_modeling.utils.get_sentinel_user_id, editable=False, on_delete=django.db.models.deletion.DO_NOTHING, related_name='created_%(app_label)s_%(class)s', related_query_name='query_created_%(app_label)s_%(class)ss', to=settings.AUTH_USER_MODEL),
        ),
    ]
