# Generated by Django 4.2.6 on 2023-11-13 00:25

from django.db import migrations, models

import django_anchor_modeling.fields


class Migration(migrations.Migration):
    dependencies = [
        ("dataviewer", "0003_remove_businesstodatafieldmap_metadata"),
    ]

    operations = [
        migrations.CreateModel(
            name="BusinessToQueryMap",
            fields=[
                ("created", models.DateTimeField(auto_now_add=True)),
                (
                    "id",
                    django_anchor_modeling.fields.BusinessIdentifierField(
                        max_length=255, primary_key=True, serialize=False
                    ),
                ),
                ("description", models.TextField()),
                ("main_model_class", models.CharField(max_length=255)),
                ("select_related", models.JSONField(default=list)),
                ("prefetch_related", models.JSONField(default=list)),
                ("only", models.JSONField(default=list)),
                ("field_processors", models.JSONField(default=dict)),
            ],
            options={
                "abstract": False,
            },
        ),
    ]
